AdjustedArithmeticMeanRankIndex
===============================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: AdjustedArithmeticMeanRankIndex
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~AdjustedArithmeticMeanRankIndex.name
      ~AdjustedArithmeticMeanRankIndex.synonyms
      ~AdjustedArithmeticMeanRankIndex.value_range

   .. rubric:: Attributes Documentation

   .. autoattribute:: name
   .. autoattribute:: synonyms
   .. autoattribute:: value_range
